@@ -329,7 +329,7 @@ class GAlearner:
         Identify unique target labels and remember them.
         
         :param list/np.array train_targets: The training target space (or any other for that matter)
-        :returns label_map, inverse_label_map: Two dicts, mapping to and from encoded space suitable for autoML loopings.
+        :return label_map, inverse_label_map: Two dicts, mapping to and from encoded space suitable for autoML loopings.
 
         """
 
@@ -347,7 +347,7 @@ class GAlearner:
         
         :param list/np.array targets: The target space
         :param bool inverse: Boolean if map to origin space or not (default encodes into continuum)
-        :returns list new_targets: Encoded target space
+        :return list new_targets: Encoded target space
 
         """
         if inverse:
@@ -460,7 +460,7 @@ class GAlearner:
 
     def return_dataframe_from_text(self, text):
         """
-        A helper method that returns a given dataframe from text.
+        A helper method that return a given dataframe from text.
 
         :param list/pd.Series text: list of texts.
         :return parsed df: A parsed text (a DataFrame)
@@ -863,7 +863,7 @@ class GAlearner:
         Predict on new instances. Note that the prediction is actually a maxvote across the hall-of-fame.
 
         :param list/pd.Series instances: predict labels for new instances = texts.
-        :returns np.array all_predictions: Vector of predictions (decoded)
+        :return np.array all_predictions: Vector of predictions (decoded)
 
         """
 
@@ -1191,21 +1191,23 @@ class GAlearner:
         return dfx
 
     def evolve(self,
-               nind=10,
-               crossover_proba=0.4,
-               mutpb=0.15,
-               stopping_interval=20,
-               strategy="evolution",
-               validation_type="cv"):
+               nind = 10,
+               crossover_proba = 0.4,
+               mutpb = 0.15,
+               stopping_interval = 20,
+               strategy = "evolution",
+               representation_step_only = False,
+               validation_type = "cv"):
         """The core evolution method. First constrain the maximum number of features to be taken into account by lowering the bound w.r.t performance.
         next, evolve.
 
-        :param nind: number of individuals (int)
-        :param crossover_proba: crossover probability (float)
-        :param mutpb: mutation probability (float)
-        :param stopping_interval: stopping interval -> for how long no improvement is tolerated before a hard reset (int)
-        :param strategy: type of evolution (str)
-        :param validation_type: type of validation, either train_val or cv (cross validation or train-val split)
+        :param int nind: number of individuals (int)
+        :param float crossover_proba: crossover probability (float)
+        :param float mutpb: mutation probability (float)
+        :param int stopping_interval: stopping interval -> for how long no improvement is tolerated before a hard reset (int)
+        :param str strategy: type of evolution (str)
+        :param bool representation_step_only: Learn only the feature transformations, skip the evolution. Suitable for custom experiments with transform()
+        :param str validation_type: type of validation, either train_val or cv (cross validation or train-val split)
         """
 
         self.validation_type = validation_type
@@ -1213,6 +1215,9 @@ class GAlearner:
         self.popsize = nind
         self.instantiate_validation_env()
 
+        if representation_step_only: ## Skip the remainder
+            return self
+        
         if self.verbose:
             logging.info("Evolution will last for ~{}h ..".format(
                 self.max_time))
@@ -1276,7 +1281,7 @@ class GAlearner:
 
         stopping = 1
         cf1 = 0
-
+        
         ## Start the evolution.
         while True:
 
